pub struct FwLog {
pub packet_filter: PacketFilter,
pub ip_specific: IpSpecific,
pub ip_data: IpData,
pub protocol: Protocol,
pub proto_info: ProtoInfo,
}Expand description
A struct to represent a firewall log
Fields
packet_filter: PacketFilterInformation about the packet filter, such as the rule that triggered the log entry and the associated interface, action, and direction.
ip_specific: IpSpecificInformation specific to either IPv4 or IPv6 packets.
ip_data: IpDataPacket length and source/destination IP addresses.
protocol: ProtocolThe used protocol (e.g., TCP, UDP)
proto_info: ProtoInfoProtocol-specific information, including flags and control data.